#/***************************************************************************
#*                                                                          *
#*  OpenNI 1.x Alpha                                                        *
#*  Copyright (C) 2011 PrimeSense Ltd.                                      *
#*                                                                          *
#*  This file is part of OpenNI.                                            *
#*                                                                          *
#*  OpenNI is free software: you can redistribute it and/or modify          *
#*  it under the terms of the GNU Lesser General Public License as published*
#*  by the Free Software Foundation, either version 3 of the License, or    *
#*  (at your option) any later version.                                     *
#*                                                                          *
#*  OpenNI is distributed in the hope that it will be useful,               *
#*  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
#*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the            *
#*  GNU Lesser General Public License for more details.                     *
#*                                                                          *
#*  You should have received a copy of the GNU Lesser General Public License*
#*  along with OpenNI. If not, see <http://www.gnu.org/licenses/>.          *
#*                                                                          *
#***************************************************************************/
#-------------Imports----------------------------------------------------------#
from xml.dom.minidom import parse, parseString
import win32con,pywintypes,win32api
from time import strftime
import logging
import glob
import os
import re
import sys
import subprocess
import shutil
import stat
import uuid
path_to_base = os.path.dirname(os.path.abspath('../../../Externals/PSCommon/Windows/CreateRedist/redist_base.py'))
if path_to_base not in sys.path:
    sys.path.insert(0, path_to_base)
import redist_base

class RedistOpenNI(redist_base.RedistBase):
    def __init__(self):
        #RedistBase.__init__(self)
        super(RedistOpenNI,self).__init__()
        self.VC_version = 10
        self.project_is_2010 = True
        self.vc_build_bits = "32"
        self.config_xml_filename = "OpenNi_Config.xml"
        self.redist_name = "OpenNI"
        self.redist_internal_name = 'OpenNI'
        self.product_name = 'OpenNI'
        self.doxy_file_name = 'Doxyfile'
        self.write_2010_sample_dependency = True
        self.internal_conf_name = 'Dev'
        self.SCRIPT_DIR = os.getcwd()

    def init_win_sdk_vars(self):
        """find Windows SDK install dir"""
        WIN_SDK_KEY = (win32con.HKEY_LOCAL_MACHINE, r"SOFTWARE\Microsoft\Microsoft SDKs\Windows")
        WIN_SDK_VALUES = [("CurrentInstallFolder", win32con.REG_SZ)]
        self.WIN_SDK_INST_DIR = redist_base.get_reg_values(WIN_SDK_KEY, WIN_SDK_VALUES)[0]

    def init_version_vars(self):
        """
        Init Verison vars.
        currently not called in script. Taken from Redist_OpenNi.
        """
        version_file = open(self.WORK_DIR + "/Include/XnVersion.h").read()
        version_major = re.search(r"define XN_MAJOR_VERSION (\d+)", version_file).groups()[0]
        self.version_minor = re.search(r"define XN_MINOR_VERSION (\d+)", version_file).groups()[0]
        version_maintenance = re.search(r"define XN_MAINTENANCE_VERSION (\d+)", version_file).groups()[0]
        version_build = re.search(r"define XN_BUILD_VERSION (\d+)", version_file).groups()[0]
        self.version_string = version_major + "." + self.version_minor + "." + version_maintenance + "." + version_build

    def build_project(self):
        #--------------Build Project---------------------------------------------------#
        self.build_proj_solution()
        self.build_java_wrapper()
        self.build_other_samples()
        self.build_dotnet_policy()
        self.make_doxy()
        self.create_redist_dir()
        self.copy_files_to_redist()
        self.creating_samples()
        self.remove_read_only_attributes()

    def build_dotnet_policy(self):
        # Build the .NET publisher policy assembly (unfortunately, this should be done manually):
        for minor in range(1, int(self.version_minor)+1):
            policy_name = 'Policy.1.' + str(minor) + '.OpenNI.Net.dll'
            cmd = self.WIN_SDK_INST_DIR + '\\Bin\\al.exe'
            cmd += ' /link:' + self.WORK_DIR + '\\Wrappers\\OpenNI.Net\\PublisherPolicy.config'
            cmd += ' /out:' + self.WORK_DIR + '\\Platform\\Win32\\' + self.bin_dir + '\\Release\\' + policy_name
            cmd += ' /keyFile:' + self.WORK_DIR + '\\Platform\\Win32\\Build\\Wrappers\\OpenNI.Net\\OpenNI.snk'
            cmd += ' /platform:'
            if self.vc_build_bits=="32":
                cmd += 'x86'
            else:
                cmd += 'x64'
            cmd += ' /version:' + self.version_string

            if subprocess.call(cmd) != 0:
                print("Building Publisher Policy Failed!!")
                self.logger.critical("Building Publisher Policy Failed!")
                self.finish_script(1)

    def build_java_wrapper(self):
        "Builds the Java wrapper"
        self.build_other_proj(self.WORK_DIR + '\\Platform\\Win32\\Build\\Wrappers\\OpenNI.java')

    def update_installer_clr_policy(self):
        updater = UpdateInstallerCLRPolicy(os.path.join(self.WORK_DIR,self.inst_proj_path))
        for minor in range(1, int(self.version_minor)+1):
            [missing,broken] = updater.is_missing(minor)
            if broken:
                self.logger.error('WXS file seems to be broken on definitions of dotnet policy for version 1.%d.'%minor)
            elif missing:
                self.logger.info('WXS file missing definitions of dotnet policy for version 1.%d.'%minor)
                updater.add_policy_clauses(minor)
                self.logger.info('WXS was succesfully updated to contain definitions of dotnet policy for version 1.%d.'%minor)
            else:
                self.logger.info('WXS contains definitions of dotnet policy for version 1.%d.'%minor)

    def copy_doxy_files(self):
        os.system("""copy "html\*.chm" ..\..\Documentation""")

    def copy_files_to_redist(self):
        #-------------Copy files to redist---------------------------------------------#
        print("* Copying files to redist dir...")
        self.logger.info("Copying files to redist dir...")

        os.chdir(self.WORK_DIR + "\\Platform\\Win32")

        #license
        os.system ("copy \"..\\..\\GPL.txt\" Redist")
        os.system ("copy \"..\\..\\LGPL.txt\" Redist")

        #bin
        os.system ("copy " + self.bin_dir + "\\Release\\OpenNI*.dll Redist\\" + self.bin_dir)
        os.system ("copy " + self.bin_dir + "\\Release\\OpenNI.Net.dll Redist\\" + self.bin_dir)
        os.system ("copy " + self.bin_dir + "\\Release\\Policy.1.*.OpenNI.Net.dll Redist\\" + self.bin_dir)
        #os.system ("copy " + "..\\..\\Wrappers\\OpenNI.Net\\PublisherPolicy.config Redist\\" + self.bin_dir)
        os.system ("copy " + self.bin_dir + "\\Release\\nimCodecs*.dll Redist\\" + self.bin_dir)
        os.system ("copy " + self.bin_dir + "\\Release\\nimMockNodes*.dll Redist\\" + self.bin_dir)
        os.system ("copy " + self.bin_dir + "\\Release\\nimRecorder*.dll Redist\\" + self.bin_dir)
        os.system ("copy " + self.bin_dir + "\\Release\\niReg*.exe Redist\\" + self.bin_dir)
        os.system ("copy " + self.bin_dir + "\\Release\\niLicense*.exe Redist\\" + self.bin_dir)
        os.system ("copy " + self.bin_dir + "\\Release\\OpenNI.jni.dll Redist\\" + self.bin_dir)
        os.system ("copy " + self.bin_dir + "\\Release\\org.OpenNI.jar Redist\\" + self.bin_dir)

        for minor in range(1, int(self.version_minor)+1):
            policy_congfig_name = 'PublisherPolicy1.' + str(minor) + '.config'
            os.system ("copy " + "..\\..\\Wrappers\\OpenNI.Net\\PublisherPolicy.config Redist\\" + self.bin_dir + "\\" + policy_congfig_name)

        #lib
        os.system ("copy " + self.lib_dir + "\\Release\\*.* Redist\\" + self.lib_dir)

        #docs
        os.system ("copy \"..\\..\\Documentation\\*.pdf\" Redist\\Documentation")
        os.system ("copy \"..\\..\\Documentation\\*.chi\" Redist\\Documentation")
        os.system ("copy \"..\\..\\Documentation\\*.chm\" Redist\\Documentation")

        #include
        os.system ("xcopy /S ..\\..\\Include\\* Redist\\Include\\")

        #driver
        os.system ("xcopy /S Driver\\Bin\\*.* Redist\\Driver\\")

        #samples
        os.system ("copy Redist\\Samples\\" + self.bin_dir + "\\Release\\*.* Redist\\Samples\\" + self.bin_dir + "\\Debug")
        os.system ("xcopy /S Build\\Res\\*.* Redist\\Samples\\Res\\")

        #data
        os.system ("copy ..\\..\\Data\\SamplesConfig.xml Redist\\Data\\SamplesConfig.xml")

        # Copy the glut dll to the samples
        os.system ("xcopy /S .\\" + self.bin_dir + "\\Release\\glut*.dll Redist\\Samples\\" + self.bin_dir + "\\Release\\")
        os.system ("xcopy /S .\\" + self.bin_dir + "\\Release\\glut*.dll Redist\\Samples\\" + self.bin_dir + "\\Debug\\")

        # Copy the wrappers to the samples
        shutil.copy(os.path.join(self.bin_dir, "Release", "OpenNI.net.dll"), os.path.join("Redist", "Samples", self.bin_dir, "Release"))
        shutil.copy(os.path.join(self.bin_dir, "Release", "OpenNI.net.dll"), os.path.join("Redist", "Samples", self.bin_dir, "Debug"))
        shutil.copy(os.path.join(self.bin_dir, "Release", "org.OpenNI.jar"), os.path.join("Redist", "Samples", self.bin_dir, "Release"))
        shutil.copy(os.path.join(self.bin_dir, "Release", "org.OpenNI.jar"), os.path.join("Redist", "Samples", self.bin_dir, "Debug"))

        # Copy the release notes
        os.system ("copy .\\ReleaseNotes.txt Redist\\Documentation\\")

        os.chdir(self.WORK_DIR)

    def fix_file(self,arg,dirname,fname):
        "Fixes paths for all the files in fname"
        for filename in fname:
            filePath = dirname + "\\" + filename
            if os.path.isdir(filePath):
                continue

            ext = ['icproj','vcproj','vcxproj','csproj','cpp','h','c','ini','cs','py','bat','java']
            file_ext = os.path.splitext(filename)[1][1:]
            if file_ext in ext:
                file = open(filePath, "r+")
                s = file.read()
                file.seek(0)

                olds = s
                # Fix include paths
                s = re.sub(r"../../../../../Include",r"$(OPEN_NI_INCLUDE)",s)
                s = re.sub(r"..\\..\\..\\..\\..\\Include",r"$(OPEN_NI_INCLUDE)",s)
                
                sample_name = os.path.basename(dirname)
                s = re.sub(r"..\\..\\..\\..\\..\\Samples\\" + sample_name, r".", s)
                s = re.sub(r"../../../../../Samples/" + sample_name, r".", s)
                
                # fix path to "Data" folder
                s = re.sub(r"..\\\\..\\\\..\\\\..\\\\Data\\",r"..\\\\..\\\\..\\\\Data\\",s)
                s = re.sub(r"..\\..\\..\\..\\Data\\",r"..\\..\\..\\Data\\",s)
                s = re.sub("../../../../Data/",r"../../../Data/",s)

                # fix path to res files
                s = re.sub(r"..\\..\\Res\\",r"..\\Res\\",s)

                # fix path to java build script
                s = re.sub(r"..\\..\\BuildJava.py", r"..\\Build\\BuildJava.py", s)
                
                # fix bin and lib path for 32 bit configuration
                s = re.sub(r"../../../Bin/",r"../Bin/",s)
                s = re.sub(r"..\\..\\..\\Bin\\",r"../Bin/",s)
                s = re.sub(r"../../../Lib/\$\(Configuration\)",r"$(OPEN_NI_LIB)",s)
                s = re.sub(r"..\\..\\..\\Lib\\\$\(Configuration\)",r"$(OPEN_NI_LIB)",s)
                
                # fix bin and lib path for 64 bit configuration
                s = re.sub(r"../../../Bin64/",r"../Bin64/",s)
                s = re.sub(r"..\\..\\..\\Bin64\\",r"../Bin64/",s)
                s = re.sub(r"../../../Lib64/\$\(Configuration\)",r"$(OPEN_NI_LIB64)",s)
                s = re.sub(r"..\\..\\..\\Lib64\\\$\(Configuration\)",r"$(OPEN_NI_LIB64)",s)

                # fix general path problems
                s = re.sub(r"..\\..\\..\\..\\..\\",r"..\\..\\",s)
                s = re.sub(r"../../../../../",r"../../",s)
                
                # remove source control integraion (if exists)
                s = re.sub(r".*SccProjectName=\".*", r"", s);
                s = re.sub(r".*SSccAuxPath=\".*", r"", s);
                s = re.sub(r".*SccLocalPath=\".*", r"", s);

                # fix csproj link problem
                if file_ext == "csproj":
                    sample_name = os.path.basename(dirname)
                    link_re = r"<Compile Include=\"\.\\(?P<file>.*)\">\n"
                    link_re += r"\s*<Link>(?P=file)</Link>"
                    compiled_re = re.compile(link_re, re.MULTILINE)
                    s = compiled_re.sub("<Compile Include=\"\g<file>\">", s)
                    
                # remove dependencies from samples vcxproj to non-sample projects
                if file_ext == "vcxproj":
                    # dependency to another sample will be to ..\<sample>
                    compiled_start = re.compile(r"<ProjectReference Include=\"\.\.\\\.\.\\")
                    compiled_end = re.compile(r"</ProjectReference>")
                    while True:
                        match_start = compiled_start.search(s)
                        if match_start is None:
                            break
                        # look for end
                        match_end = compiled_end.search(s, match_start.end())
                        s = s[:match_start.start()] + s[match_end.end():]
                    
                file.truncate()
                file.write(s)
                file.close()

    def redist_openni(self):
        """
        Main Script.
        """
        self.init_logger(self.redist_name)
        self.check_args(sys.argv)
        self.init_vars()
        self.init_vs_vars()
        print (("\n*** Build target is:" + self.vc_build_bits + " Doxy:" + str(self.Make_Doxy) + " Rebuild:" + sys.argv[3] + " VC Version:" + str(self.VC_version) + " ***"))
        self.init_win_sdk_vars()
        self.init_version_vars()
        self.print_message()
        self.logger.info("PrimeSense OpenNI Redist Started")
        self.build_project()
        self.fixing_files()
        
        # set OpenNI environment variables to point to the redist folder (so that samples can compile correctly)
        REDIST_DIR = os.path.join(self.WORK_DIR,"Platform","Win32","Redist")
        os.environ['OPEN_NI_INCLUDE'] = REDIST_DIR + "\\Include"
        os.environ['OPEN_NI_LIB'] = REDIST_DIR + "\\Lib"
        os.environ['OPEN_NI_LIB64'] = REDIST_DIR + "\\Lib64"
        self.build_samples()
        self.update_installer_clr_policy()
        [dev,redist] = self.make_installer(self.SCRIPT_DIR)
        if not dev:
            return 1
        else:
            if not redist:
                return 1
        self.clean_up()
        return 0


class UpdateInstallerCLRPolicy:
    """
    Covers up for missing parts in the installer
    that are responsible for dotnet-publisher-policy stuff.
    """
    def __init__(self,inst_proj_full_path):
        self.wxs_file = os.path.join(inst_proj_full_path,'OpenNI.wxs')
    def is_missing(self, minor):
        """
        Returns [missing,broken] if this version is missing,
        or broken if only one of the clauses exist.
        """
        #checks the WXS file if 2 patterns are found
        #<Component Id="OpenNIPolicy1.%d"
        #<ComponentRef Id="OpenNIPolicy1.%d"/>
        comp_id_clause = False
        rev_re = re.compile('<Component Id=\"OpenNIPolicy1\.%d\"'%minor)
        all_lines = open(self.wxs_file).readlines()
        re_res = rev_re.search(str(all_lines))
        if re_res:
            comp_id_clause = True
        comp_ref_clause = False
        comp_ref_str = '<ComponentRef Id=\"OpenNIPolicy1\.%d\"/>'%minor
        rev_re = re.compile(comp_ref_str)
        re_res = rev_re.search(str(all_lines))
        if re_res:
            comp_ref_clause = True
        missing = not comp_ref_clause and not comp_id_clause
        broken = (comp_id_clause and not comp_ref_clause) or (comp_ref_clause and not comp_id_clause)
        return [missing,broken]
    def add_policy_clauses(self,minor):
        """
        Adds the two clauses into the file.
        """
        comp_ref_str = '<ComponentRef Id=\"OpenNIPolicy1.%d\"/>'%minor
        comp_ref_anchor = '<ComponentRef Id="OpenNINET"/>'
        redist_base.regx_replace(comp_ref_anchor,'%s\n%s'%(comp_ref_anchor,comp_ref_str),self.wxs_file)

        guid = uuid.uuid1()
        comp_id_str = r'<Component Id="OpenNIPolicy1.%d" Guid="%s" DiskId="1">'%(minor,str(guid)) + '\n' + \
        r'<File Id="OpenNIPolicy1.%d" Name="Policy.1.%d.OpenNI.Net.dll" Assembly=".net" KeyPath="yes" '%(minor,minor) +  \
        r'Source="$(var.OpenNIFilesDir)\\bin$(var.PlatformSuffix)\Policy.1.%d.OpenNI.Net.dll" />'%(minor) + '\n' + \
        r'<File Id="OpenNIPolicyConfig1.%d" Name="PublisherPolicy1.%d.config" KeyPath="no" '%(minor,minor) + \
        r'Source="$(var.OpenNIFilesDir)\\bin$(var.PlatformSuffix)\PublisherPolicy1.%d.config" />'%(minor) + '\n' + \
        r'</Component>'
        comp_id_anchor = r'<Component Id="OpenNINET"'
        redist_base.regx_replace(comp_id_anchor,'%s\n%s'%(comp_id_str,comp_id_anchor),self.wxs_file)

if __name__ == "__main__":
    redist = RedistOpenNI()
    rc =  redist.redist_openni()
    redist.finish_script(rc)



#/***************************************************************************
#*                                                                          *
#*  OpenNI 1.x Alpha                                                        *
#*  Copyright (C) 2011 PrimeSense Ltd.                                      *
#*                                                                          *
#*  This file is part of OpenNI.                                            *
#*                                                                          *
#*  OpenNI is free software: you can redistribute it and/or modify          *
#*  it under the terms of the GNU Lesser General Public License as published*
#*  by the Free Software Foundation, either version 3 of the License, or    *
#*  (at your option) any later version.                                     *
#*                                                                          *
#*  OpenNI is distributed in the hope that it will be useful,               *
#*  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
#*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the            *
#*  GNU Lesser General Public License for more details.                     *
#*                                                                          *
#*  You should have received a copy of the GNU Lesser General Public License*
#*  along with OpenNI. If not, see <http://www.gnu.org/licenses/>.          *
#*                                                                          *
#***************************************************************************/
#
import sys
import os
import re
from datetime import date

VERSION_MAJOR = 1
VERSION_MINOR = 5
VERSION_MAINTENANCE = 4
VERSION_BUILD = 0

class UpdateVersion:
    def main(self):
        self.version_major = VERSION_MAJOR
        self.version_minor = VERSION_MINOR
        self.version_maintenance = VERSION_MAINTENANCE
        self.version_build = VERSION_BUILD
        # ----------------------- MAIN -------------------------
        if len(sys.argv) == 5:
            self.version_major=int(sys.argv[1])
            self.version_minor=int(sys.argv[2])
            self.version_maintenance=int(sys.argv[3])
            self.version_build=int(sys.argv[4])

        if (self.version_major > 9):
            print( "Illegal major version")
            sys.exit()

        if (self.version_minor > 99):
            print ("Illegal minor version")
            sys.exit()

        if (self.version_maintenance > 99):
            print ("Illegal maintenance version")
            sys.exit()

        if (self.version_build > 9999):
            print ("Illegal build version")
            sys.exit()

        self.strVersion = str(self.version_major) + "." + str(self.version_minor) + "." + str(self.version_maintenance) + "." + str(self.version_build)

        print (("Going to update files to version: %d.%d.%d.%d" % (self.version_major, self.version_minor, self.version_maintenance, self.version_build)))

        self.update_self_defs("./UpdateVersion.py")
        self.update_redist_defs("./RedistMaker.bat")
        self.update_redist_script("./Redist_OpenNI.py")
        self.update_redist_eng_defs("./OpenNi_Config.xml")
        self.update_src_ver_defs("../../../Include/XnVersion.h")
        self.update_assembly_info("../Build/Res/AssemblyInfo-OpenNI.cs")
        self.update_assembly_info("../../Linux/Build/Res/AssemblyInfo-OpenNI.cs")
        self.update_wix("../Install/OpenNI/Includes/OpenNIVariables.wxi")
        self.update_publisher_policy("../../../Wrappers/OpenNI.Net/PublisherPolicy.config")
        self.update_doxygen("../../../Source/DoxyGen/Doxyfile")
        self.update_release_notes("../../../Platform/Win32/Build/ReleaseNotes.txt")

        try:
            self.update_redist_defs("../../../ExportOpenSource.bat")
        except:
            print ("Skipping the export script...")

        print ("\n*** Done ***")
    def regx_replace(self,findStr,repStr,filePath):
        "replaces all findStr by repStr in file filePath using regualr expression"
        findStrRegx = re.compile(findStr)
        tempName=filePath+'~~~'
        os.system("attrib -r " + filePath)
        input = open(filePath)
        output = open(tempName,'w')
        for s in input:
            output.write(findStrRegx.sub(repStr,s))
        output.close()
        input.close()
        os.remove(filePath)
        os.rename(tempName,filePath)

    def update_self_defs (self,filePath):
        print(( "Updating self version defines: " + filePath))
        self.regx_replace("VERSION_MAJOR = \d+\n", "VERSION_MAJOR = " + str(self.version_major) + "\n", filePath)
        self.regx_replace("VERSION_MINOR = \d+\n", "VERSION_MINOR = " + str(self.version_minor) + "\n", filePath)
        self.regx_replace("VERSION_MAINTENANCE = \d+\n", "VERSION_MAINTENANCE = " + str(self.version_maintenance) + "\n", filePath)
        self.regx_replace("VERSION_BUILD = \d+\n", "VERSION_BUILD = " + str(self.version_build) + "\n", filePath)

    def update_src_ver_defs (self,filePath):
        print(( "Updating source version defines: " + filePath))
        self.regx_replace("#define XN_MAJOR_VERSION (.*)", "#define XN_MAJOR_VERSION " + str(self.version_major), filePath)
        self.regx_replace("#define XN_MINOR_VERSION (.*)", "#define XN_MINOR_VERSION " + str(self.version_minor), filePath)
        self.regx_replace("#define XN_MAINTENANCE_VERSION (.*)", "#define XN_MAINTENANCE_VERSION " + str(self.version_maintenance), filePath)
        self.regx_replace("#define XN_BUILD_VERSION (.*)", "#define XN_BUILD_VERSION " + str(self.version_build), filePath)

    def update_redist_defs (self,filePath):
        print(( "Updating RedistMaker version defines: " + filePath))
        self.regx_replace("set MAJOR_VERSION=(.*)", "set MAJOR_VERSION=" + str(self.version_major), filePath)
        self.regx_replace("set MINOR_VERSION=(.*)", "set MINOR_VERSION=" + str(self.version_minor), filePath)
        self.regx_replace("set MAINTENANCE_VERSION=(.*)", "set MAINTENANCE_VERSION=" + str(self.version_maintenance), filePath)
        self.regx_replace("set BUILD_VERSION=(.*)", "set BUILD_VERSION=" + str(self.version_build), filePath)

    def update_redist_script (self,filePath):
        print(("Updating Redist script version defines: " + filePath))
        self.regx_replace("set MAJOR_VERSION=(.*)", "set MAJOR_VERSION=" + str(self.version_major), filePath)
        self.regx_replace("set MINOR_VERSION=(.*)", "set MINOR_VERSION=" + str(self.version_minor), filePath)
        self.regx_replace("set MAINTENANCE_VERSION=(.*)", "set MAINTENANCE_VERSION=" + str(self.version_maintenance), filePath)
        self.regx_replace("set BUILD_VERSION=(.*)", "set BUILD_VERSION=" + str(self.version_build), filePath)

    def update_redist_eng_defs (self,filePath):
        print (("Updating Redist Engine version defines: " + filePath))
        self.regx_replace("  <VERSION_NUMBER>(\d+).(\d+).(\d+)</VERSION_NUMBER>", "  <VERSION_NUMBER>" + str(self.version_major) + "." + str(self.version_minor) + "." + str(self.version_maintenance) + "</VERSION_NUMBER>", filePath)

    def update_assembly_info (self,filePath):
        print (("Updating assembly info: " + filePath))
        self.regx_replace(r"^\[assembly: AssemblyVersion\(\"(.*)\"\)\]", "[assembly: AssemblyVersion(\"" + str(self.version_major) + "." + str(self.version_minor) + "." + str(self.version_maintenance) + "." + str(self.version_build) + "\")]", filePath)
        self.regx_replace(r"^\[assembly: AssemblyFileVersion\(\"(.*)\"\)\]", "[assembly: AssemblyFileVersion(\"" + str(self.version_major) + "." + str(self.version_minor) + "." + str(self.version_maintenance) + "." + str(self.version_build) + "\")]", filePath)

    def update_wix (self,filePath):
        print (("Updating wix: " + filePath))
        self.regx_replace("define MajorVersion=(.*)", "define MajorVersion=" + str(self.version_major) + "?>", filePath)
        self.regx_replace("define MinorVersion=(.*)", "define MinorVersion=" + str(self.version_minor) + "?>", filePath)
        self.regx_replace("define MaintenanceVersion=(.*)", "define MaintenanceVersion=" + str(self.version_maintenance) + "?>", filePath)
        self.regx_replace("define BuildVersion=(.*)", "define BuildVersion=" + str(self.version_build) + "?>", filePath)

    def update_publisher_policy (self,filePath):
        print(( "Updating publisher policy: " + filePath))
        self.regx_replace("oldVersion=\"1.1.0.31 - (.*)\"", "oldVersion=\"1.1.0.31 - " + self.strVersion + "\"", filePath)
        self.regx_replace("newVersion=\"(.*)\"", "newVersion=\"" + self.strVersion + "\"", filePath)

    def update_doxygen (self,filePath):
        print (("Updating doxygen: " + filePath))
        self.regx_replace("PROJECT_NAME\s*=\s*\"OpenNI (\d+)\.(\d+)\.(\d+)\"", "PROJECT_NAME = \"OpenNI " + str(self.version_major) + "." + str(self.version_minor) + "." + str(self.version_maintenance) + "\"", filePath)

    def update_release_notes (self,filePath):
        print (("Updating release notes: " + filePath))

        tempName = filePath + '~~~'
        os.system("attrib -r " + filePath)
        input = open(filePath)
        output = open(tempName, 'w')
        lines = input.readlines()
        input.close()
        today = date.today()

        lines[0] = 'OpenNI ' + str(self.version_major) + '.' + str(self.version_minor) + '.' + str(self.version_maintenance) + ' Build ' + str(self.version_build) + '\n'
        lines[1] = today.strftime('%B ') + str(today.day) + ' ' + str(today.year) + '\n'
        
        for s in lines:
            output.write(s)
        output.close()
        os.remove(filePath)
        os.rename(tempName,filePath)        
        
if __name__ == '__main__':
    UpdateVersion().main()



#/****************************************************************************
#*      THIS file should be DUPLICATED IN BOTH                               *
#*      Engine\Platform\Win32\CreateRedist                                   *
#*  AND OpenNI\Platform\Win32\CreateRedist                                   *
#*                                                                           *
#****************************************************************************/

#/****************************************************************************
#*                                                                           *
#*  PrimeSense OpenNI & Sensor                                               *
#*  Copyright (C) 2010 PrimeSense Ltd.                                       *
#*                                                                           *
#*  This file is part of PrimeSense Common.                                  *
#*                                                                           *
#*  PrimeSense OpenNI & Sensor are free software: you can redistribute       *
#*  it and/or modify                                                         *
#*  it under the terms of the GNU Lesser General Public License as published *
#*  by the Free Software Foundation, either version 3 of the License, or     *
#*  (at your option) any later version.                                      *
#*                                                                           *
#*  PrimeSense OpenNI & Sensor are distributed in the hope that they will    *
#*  be useful,                                                               *
#*  but WITHOUT ANY WARRANTY; without even the implied warranty of           *
#*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the             *
#*  GNU Lesser General Public License for more details.                      *
#*                                                                           *
#*  You should have received a copy of the GNU Lesser General Public License *
#*  along with PrimeSense OpenNI & Sensor.                                   *
#*  If not, see <http://www.gnu.org/licenses/>.                              *
#*                                                                           *
#****************************************************************************/

#-------------Imports----------------------------------------------------------#
from xml.dom.minidom import parse, parseString
import win32con,pywintypes,win32api
from time import strftime
import logging
import glob
import os
import re
import sys
import subprocess
import shutil
import stat
import threading

#-------------Functions--------------------------------------------------------#

def is_64_bit_platform():
    result = False
    import platform
    (bits,linkage) = platform.architecture()
    matchObject = re.search('64',bits)
    result = matchObject is not None
    return result

def write_dependencides(sln_file, all_samples,sample):
    sln_file.write("\tProjectSection(ProjectDependencies) = postProject\n")
    for depend in sample.dependencies:
        sln_file.write("\t\t" + all_samples[depend].project_guid + " = " + all_samples[depend].project_guid + "\n")
    sln_file.write("\tEndProjectSection\n")

def remove_readonly(path):
    for root, dirs, files in os.walk(path):
        for fname in files:
            full_path = os.path.join(root, fname)
            os.chmod(full_path ,stat.S_IWRITE)

def regx_replace(findStr,repStr,filePath):
    "replaces all findStr by repStr in file filePath using regualr expression"
    findStrRegx = re.compile(findStr)
    tempName=filePath+'~~~'
    input = open(filePath)
    output = open(tempName,'w')
    for s in input:
        output.write(findStrRegx.sub(repStr,s))
    output.close()
    input.close()
    os.remove(filePath)
    os.rename(tempName,filePath)

def get_reg_values(reg_key, value_list):
    # open the reg key
    try:
        reg_key = win32api.RegOpenKeyEx(*reg_key)
    except pywintypes.error as e:
        raise Exception("Failed to open registry key!")
    # Get the values
    try:
        values = [(win32api.RegQueryValueEx(reg_key, name), data_type) for name, data_type in value_list]
        # values list of ((value, type), expected_type)
        for (value, data_type), expected in values:
            if data_type != expected:
                raise Exception("Bad registry value type! Expected %d, got %d instead." % (expected, data_type))
        # values okay, leave only values
        values = [value for ((value, data_type), expected) in values]
    except pywintypes.error as e:
        raise Exception("Failed to get registry value!")
    finally:
        try:
            win32api.RegCloseKey(reg_key)
        except pywintypes.error as e:
            # We don't care if reg key close failed...
            pass
    return tuple(values)

#-------------Classes----------------------------------------------------------#
class SampleData(object):
    def __init__(self):
        self.name = ''
        self.project_dir = ''
        self.source_dir = ''
        self.project_guid = ''
        self.project_file = ''
        self.is_net = False
        self.is_other = False
        self.project_name = ''
        self.redist_dir = ''
        self.dependencies = []

    def print_():
        print((self.name))

    def __str__(self):
        return self.name

    def __eval__(self):
        return self.name

class RedistBase(object):
    def __init__(self):
        self.SCRIPT_DIR = ''
        self.VC_version = 0
        self.vc_build_bits = ""
        self.output_dir = ""
        self.final_dir = ""
        self.config_xml_filename = ""
        self.redist_name = ""
        self.redist_internal_name = ''
        self.product_name = ''
        self.doxy_file_name = ""
        self.write_2010_sample_dependency = False
        self.all_samples = None
        self.internal_conf_name = ''
        self.TIMEOUT_UPGRADE_VS10_SEC = 180
        self.project_is_2010 = False

    def finish_script(self,exit_code):
        os.chdir(self.SCRIPT_DIR)
        #logging.shutdown()
        exit(exit_code)

    def check_args(self,args):
        """
        Parse cmdline args; along them are doxy,bitness,VC.
        """
        if len(sys.argv) not in [4,5]:
            print ("Args: <Doxygen:y/n> <BuildTarget:32/64> <FullRebuild:y/n> [<VCVersion:9/10>]")
            exit(1)
        if sys.argv[1] == 'y' or sys.argv[1] == 'Yes':
            self.Make_Doxy=1
        elif sys.argv[1] == 'n' or sys.argv[1] == 'No':
            self.Make_Doxy=0
        else:
            print("Args: <Doxygen:y/n> <BuildTarget:32/64> <FullRebuild:y/n>")
            print("Doxygen param must be y or n!")
            exit(1)

        if sys.argv[2] == '32':
            self.vc_build_bits = "32"
        elif sys.argv[2] == '64':
            self.vc_build_bits = "64"
        else:
            print("Args: <Doxygen:y/n> <BuildTarget:32/64> <FullRebuild:y/n>")
            print("BuildTarget param must be 32 or 64!")
            exit(1)

        if sys.argv[3] == 'y' or sys.argv[3] == 'Yes':
            self.vc_build_type = "/Rebuild"
        elif sys.argv[3] == 'n' or sys.argv[3] == 'No':
            self.vc_build_type = "/Build"
        else:
            print("Args: <Doxygen:y/n> <BuildTarget:32/64> <FullRebuild:y/n>")
            print("FullRebuild param must be y or n!")
            exit(1)

        if self.project_is_2010:
            self.VC_version = 10
            if len(sys.argv) > 4:
                if sys.argv[4] == '9':
                    print("Project does not support VS2008!")
                    exit(1)
        else:
            self.VC_version = 9
            if len(sys.argv) > 4:
                if sys.argv[4] == '10':
                    self.VC_version = 10

    def init_vs_vars(self):
        """
        Checks for the availablity of Visual Studio to compile with.
        Currently supports VS2008 (vc9) and VS2010(vc10).
        If 64-bit platform, registry key under Software/Wow6432Node/...
        """
        self.VS_NEED_UPGRADE = 0
        try:
            if self.is_64_bit_platform:
                MSVC_KEY = (win32con.HKEY_LOCAL_MACHINE, r"SOFTWARE\Wow6432Node\Microsoft\VisualStudio\9.0")
            else:
                MSVC_KEY = (win32con.HKEY_LOCAL_MACHINE, r"SOFTWARE\Microsoft\VisualStudio\9.0")
            MSVC_VALUES = [("InstallDir", win32con.REG_SZ)]
            self.VS_INST_DIR = get_reg_values(MSVC_KEY, MSVC_VALUES)[0]
        except Exception as e:
            self.VC_version = 10
            
        if self.VC_version == 10:
            if not self.project_is_2010:
                self.VS_NEED_UPGRADE = 1
                
            if self.is_64_bit_platform:
                MSVC_KEY = (win32con.HKEY_LOCAL_MACHINE, r"SOFTWARE\Wow6432Node\Microsoft\VisualStudio\10.0")
            else:
                MSVC_KEY = (win32con.HKEY_LOCAL_MACHINE, r"SOFTWARE\Microsoft\VisualStudio\10.0")
            MSVC_VALUES = [("InstallDir", win32con.REG_SZ)]
            self.VS_INST_DIR = get_reg_values(MSVC_KEY, MSVC_VALUES)[0]

    def init_vars(self):
        """
        Initializae misc variables.
        Among them: is_64_bit_platform
        """
        self.inst_proj_path = 'Platform\\Win32\\Install\\%s\\'%self.redist_internal_name
        self.is_64_bit_platform = is_64_bit_platform()
        self.DateTimeSTR = strftime("%Y-%m-%d %H:%M:%S")
        DateSTR = strftime("%Y-%m-%d")
        CONFIG_XML = parse(self.config_xml_filename)
        self.WORK_DIR = str(CONFIG_XML.getElementsByTagName("WORK_DIR")[0].firstChild.data)
        # Fix to allow reletive path
        os.chdir(self.WORK_DIR)
        self.WORK_DIR = os.getcwd() + "\\"
        os.chdir(self.SCRIPT_DIR)
        self.VER = str(CONFIG_XML.getElementsByTagName("VERSION_NUMBER")[0].firstChild.data)
        PLATFORM = str(CONFIG_XML.getElementsByTagName("PLATFORM")[0].firstChild.data)
        self.PROJECT_SLN = str(CONFIG_XML.getElementsByTagName("PROJECT_SLN")[0].firstChild.data)
        self.SAMPLES_SLN = str(CONFIG_XML.getElementsByTagName("SAMPLES_SLN")[0].firstChild.data)
        self.PROJECT_NAME = str(CONFIG_XML.getElementsByTagName("PROJECT")[0].firstChild.data)
        self.BUILD_DIR = os.path.join(self.WORK_DIR, "Platform", "Win32", "Build")

        ver_regx = re.compile("SDK \d.*\s")
        global samples_proj_list
        global samples_guid_list
        global samples_guid_list_net
        samples_proj_list = []
        samples_guid_list = []
        samples_guid_list_net = []

        if self.vc_build_bits=="32":
            self.bin_dir = "Bin"
            self.lib_dir = "Lib"
            self.vc_build_platform = "Win32"
            self.output_dir = "Output32"
            self.final_dir = "Final32"
        else:
            self.bin_dir = "Bin64"
            self.lib_dir = "Lib64"
            self.vc_build_platform = "x64"
            self.output_dir = "Output64"
            self.final_dir = "Final64"

    def init_logger(self,name):
        """
        Initilizes the logger.
        """
        #-------------Log--------------------------------------------------------------#
        out_path = os.path.join(self.SCRIPT_DIR,self.output_dir)
        if not(os.path.exists(out_path)):
            os.mkdir(out_path)
        self.logger = logging.getLogger(name)
        hdlr = logging.FileHandler(os.path.join(self.output_dir, '%s_redist_maker.log'%name))
        formatter = logging.Formatter('%(asctime)s %(levelname)s %(message)s')
        hdlr.setFormatter(formatter)
        self.logger.addHandler(hdlr)
        self.logger.setLevel(logging.INFO)

    def print_message(self):
        """
        TO DO: fix that function in Redist_OpenNi to resemble this (better) version.
        """
        #------------Welcome Messege--------=------------------------------------------#
        print("\n");
        print("*********************************")
        print(("*   PrimeSense " + self.redist_name +  " Redist    *"))
        print(("*     " + self.DateTimeSTR + "       *"))
        print("*********************************")

    def build_proj_solution(self):
        #--------------Build Project---------------------------------------------------#
        print(("* Building " + self.PROJECT_NAME + "..."))
        path2output = os.path.join(self.SCRIPT_DIR,self.output_dir)
        if not os.path.exists(path2output):
            os.makedirs(path2output)
        path2final = os.path.join(self.SCRIPT_DIR,self.final_dir)
        if not os.path.exists(path2final):
            os.makedirs(path2final)

        self.logger.info(("Building " + self.PROJECT_NAME + "..."))
        # Set Intel Env
        os.system("set INTEL_LICENSE_FILE=C:\\Program Files\\Common Files\\Intel\\Licenses")
        # Build project solution
        os.chdir(self.WORK_DIR + self.PROJECT_SLN.rpartition("\\")[0])
        print((os.getcwd()))

        out_file = os.path.join(self.SCRIPT_DIR, self.output_dir, "Build"+self.PROJECT_NAME+".txt")
        upg_out_file = os.path.join(self.SCRIPT_DIR, self.output_dir, "Build"+self.PROJECT_NAME+"UPG"+".txt")
        if self.VS_NEED_UPGRADE == 1:
            os.system("attrib -r * /s")
            devenv_upg_cmd_str = "\""+self.VS_INST_DIR + "devenv\" " + self.PROJECT_SLN.rpartition("\\")[2]+\
                         " /upgrade > " + upg_out_file
            print(('upgrading. out put in %s'%out_file))
            print(('command is %s'%devenv_upg_cmd_str))
            my_rc = os.system(devenv_upg_cmd_str)
            print(('upgrading finished w result %d'%my_rc))
            #devenv_upg_cmd = Command(devenv_upg_cmd_str)
            #devenv_upg_cmd.run(self.TIMEOUT_UPGRADE_VS10_SEC)

        devenv_cmd = '\"'+self.VS_INST_DIR + 'devenv\" ' + self.PROJECT_SLN.rpartition("\\")[2]+\
                     " " + self.vc_build_type + " \"release|" + self.vc_build_platform + "\" /out " + \
                     out_file
        self.logger.debug('Calling vs : %s'%devenv_cmd)
        rc = subprocess.call(devenv_cmd, close_fds=True)
        self.logger.debug('Calling vs, RC: %d'%rc)
        # Get the build output
        lines = open(out_file).readlines()
        build_result = lines[-2]
        print(build_result)
        self.logger.info(build_result)
        # Check for failed build
        failed_builds = 0
        fail_to_open = 0

        temp = re.search("(\d*) failed",build_result)
        if temp != None :
            failed_builds = int(temp.group(1))

        temp2 = re.search('cannot be opened',str(lines))
        if temp2 != None :
            fail_to_open = 1

        if failed_builds != 0 or fail_to_open !=0:
            print("Building Failed!!")
            self.logger.critical("Building Failed!")
            self.finish_script(1)

        # return to work dir
        os.chdir(self.WORK_DIR)

    def make_doxy(self):
        """
        Make Doxy.
        """
        if self.Make_Doxy==1:
            print("* Creating Doxygen...")
            self.logger.info("Creating Doxygen...")
            os.chdir(os.path.join(self.WORK_DIR,"Source\\Doxygen"));
            # Replacing version number in the doxygen setup file
            res = os.system("attrib -r " + self.doxy_file_name)
            print(('removing readonly attribute for Doxyfile: ' + str(res)))
            regx_replace(self.redist_name + " \d*.\d*.\d*\s",self.PROJECT_NAME +" " + self.VER + " ",self.doxy_file_name)
            if os.path.exists(self.WORK_DIR + "\\Source\\Doxygen\\html\\"):
                os.system("rmdir /S /Q html")
            # Running doxygen
            os.system("mkdir html > null")
            #os.system("copy PSSmallLogo.jpg html > null") // where is this file ?
            doxy_out_file = os.path.join(self.SCRIPT_DIR,self.output_dir,self.PROJECT_NAME + "Doxy.txt")
            doxygen_cmd = "doxygen.exe %s > " % (self.doxy_file_name) + doxy_out_file
            os.system(doxygen_cmd)
            self.copy_doxy_files()
            os.chdir(self.WORK_DIR)
        else:
            print("Skipping Doxygen...")

    def create_redist_dir(self):
        """
        Creates directory structure for Redist.
        """
        #-------------Create Redist Dir------------------------------------------------#
        print("* Creating Redist Dir...")
        self.logger.info("Creating Redist Dir...")
        os.chdir(os.path.join(self.WORK_DIR,"Platform","Win32"))
        # Removing the old directory
        os.system("rmdir /S /Q Redist")
        # Creating new directory tree
        os.system("mkdir Redist")
        os.system("mkdir Redist\\" + self.bin_dir)
        os.system("mkdir Redist\\" + self.lib_dir)
        os.system("mkdir Redist\\Include")
        os.system("mkdir Redist\\Documentation")
        os.system("mkdir Redist\\Samples")
        os.system("mkdir Redist\\Samples\\" + self.bin_dir)
        os.system("mkdir Redist\\Samples\\" + self.bin_dir + "\\Debug")
        os.system("mkdir Redist\\Samples\\" + self.bin_dir + "\\Release")
        os.system("mkdir Redist\\Samples\\Build")
        os.system("mkdir Redist\\Samples\\Res")
        os.system("mkdir Redist\\Data")
        os.chdir(self.WORK_DIR)

    def find_samples(self):
        # returns a dictionary of all samples
        all_samples = dict()
        os.chdir(self.WORK_DIR)
        samples_list = os.listdir(os.path.join(self.BUILD_DIR,"Samples"))
        if '.svn' in samples_list:
            samples_list.remove('.svn')
        for sample in samples_list:
            sample_data = SampleData()
            sample_data.name = sample
            sample_data.source_dir = os.path.join(self.WORK_DIR, "Samples", sample)
            sample_data.project_dir = os.path.join(self.BUILD_DIR, "Samples", sample)
            sample_data.is_other = False;

            vc_proj_name = sample_data.project_dir + "\\" + sample + ".vcproj"
            cs_proj_name = sample_data.project_dir + "\\" + sample + ".csproj"
            vcx_proj_name = sample_data.project_dir + "\\" + sample + ".vcxproj"
            other_proj_name = os.path.join(sample_data.project_dir, "Build.bat")

            # check if this is a VC project
            if os.path.exists(vc_proj_name):
                sample_data.project_file = vc_proj_name

                # open it
                prj = open(vc_proj_name, 'r')
                lines = prj.readlines()
                for line in lines:
                    # Search for name
                    if sample_data.project_name == "":
                        ProjNametmp = re.search(r"Name=\"(.*)\"",line)
                        if (ProjNametmp != None):
                            sample_data.project_name = ProjNametmp.group(1)

                    # Search for GUID
                    if sample_data.project_guid == "":
                        ProjGUIDtmp = re.search(r"ProjectGUID=\"(.*)\"",line)
                        if (ProjGUIDtmp != None):
                            sample_data.project_guid = ProjGUIDtmp.group(1)

                prj.close()

            elif os.path.exists(vcx_proj_name):
                # a VC project for VS 2010
                sample_data.project_file = vcx_proj_name
                sample_data.project_name = sample

                # open it
                prj = open(vcx_proj_name, 'r')
                lines = prj.readlines()
                for line in lines:
                    # Search for name
                    if sample_data.project_name == "":
                        ProjNametmp = re.search(r"Name=\"(.*)\"",line)
                        if (ProjNametmp != None):
                            sample_data.project_name = ProjNametmp.group(1)

                    # Search for GUID
                    if sample_data.project_guid == "":
                        ProjGUIDtmp = re.search(r"<ProjectGuid>(.*)</ProjectGuid>", line)
                        if (ProjGUIDtmp != None):
                            sample_data.project_guid = ProjGUIDtmp.group(1)

                prj.close()
            
            elif os.path.exists(cs_proj_name):
                # a .NET project
                sample_data.project_file = cs_proj_name
                sample_data.is_net = True

                # open it
                prj = open(cs_proj_name, 'r')
                lines = prj.readlines()
                for line in lines:
                    # Search for name
                    if sample_data.project_name == "":
                        ProjNametmp = re.search(r"<AssemblyName>(.*)</AssemblyName>",line)
                        if (ProjNametmp != None):
                            sample_data.project_name = ProjNametmp.group(1)

                    # Search for GUID
                    if sample_data.project_guid == "":
                        ProjGUIDtmp = re.search(r"<ProjectGuid>(.*)</ProjectGuid>",line)
                        if (ProjGUIDtmp != None):
                            sample_data.project_guid = ProjGUIDtmp.group(1)

                prj.close()

            elif os.path.exists(other_proj_name):
                # some other type of project (java?)
                sample_data.project_file = other_proj_name
                sample_data.is_other = True
                sample_data.project_name = sample

            else:
                print(('Sample ' + sample + ' does not have a valid project file'))
                self.finish_script(1)

            # check if it has a special configuration
            redist_file_name = sample_data.source_dir + "\\.redist"
            if os.path.exists(redist_file_name):
                redist_file = open(redist_file_name, 'r')

                for line in redist_file.readlines():
                    # seach for dependencies
                    match = re.search("^DEPENDS=(.*)$", line)
                    if match != None:
                        sample_data.dependencies.append(match.group(1))

                redist_file.close()

            sample_data.redist_dir = "Redist\\Samples\\" + sample_data.name
            all_samples[sample_data.name] = sample_data

        return all_samples

    def get_samples(self):
        # returns a dictionary of all samples
        if self.all_samples == None:
            self.all_samples = self.find_samples()

        return self.all_samples

    def build_other_proj(self, build_dir):
        # build other (not Visual Studio) project
        ret = subprocess.call(os.path.join(build_dir, "Build.bat") + " " + self.vc_build_bits)
        if ret != 0:
            print(("Building project " + build_dir + " failed!"))
            self.logger.critical("Building project " + build_dir + " failed!")
            self.finish_script(1)

    def build_other_samples(self):
        "Builds other samples (java?)"
        all_samples = self.get_samples()
        for sample in list(all_samples.values()):
            if not sample.is_other:
                continue
            build_dir = os.path.join(self.BUILD_DIR, "Samples", sample.name)
            self.build_other_proj(build_dir)

    def creating_samples(self):
        """
        not exactly the same some further work needed.
        """
        #-------Creating samples-------------------------------------------------------#
        print("* Creating samples...")
        self.logger.info("Creating samples...")

        all_samples = self.get_samples()

        os.chdir(os.path.join(self.WORK_DIR, "Platform", "Win32"))

        # open all solution files
        if not self.project_is_2010:
            OUTFILESLN2008 = open("Redist\\Samples\\Build\\All_2008.sln",'w')
            OUTFILESLN2008.write("Microsoft Visual Studio Solution File, Format Version 10.00\n")
            OUTFILESLN2008.write("# Visual Studio 2008\n")

        if not self.project_is_2010:
            OUTFILESLN2010 = open("Redist\\Samples\\Build\\All_2010.sln",'w')
        else:
            OUTFILESLN2010 = open("Redist\\Samples\\Build\\All.sln",'w')
        
        OUTFILESLN2010.write("Microsoft Visual Studio Solution File, Format Version 11.00\n")
        OUTFILESLN2010.write("# Visual Studio 2010\n")

        # copy java build script
        try:
            shutil.copy(os.path.join("Build", "BuildJava.py"), os.path.join("Redist", "Samples", "Build"))
        except:
            pass

        # add projects
        for sample in list(all_samples.values()):
            # make dir
            os.system ("mkdir " + sample.redist_dir)
            # copy source
            os.system ("xcopy /S " + sample.source_dir + " " + sample.redist_dir)

            if sample.is_other:
                shutil.copy(sample.project_file, sample.redist_dir)
            else:
                # copy the project file to 2008 and 2010:
                prj_name_partitioned = os.path.splitext(sample.project_file);
                prj2008_filename = sample.redist_dir + "\\" + sample.name + "_2008" + prj_name_partitioned[1]

                if self.project_is_2010:
                    prj2010_filename = sample.redist_dir + "\\" + sample.name + prj_name_partitioned[1]
                else:
                    prj2010_filename = sample.redist_dir + "\\" + sample.name + "_2010" + prj_name_partitioned[1]

                if not self.project_is_2010:
                    shutil.copy(sample.project_file, prj2008_filename)
                shutil.copy(sample.project_file, prj2010_filename)

                # create reletive path to samples
                prj2008_path = "..\\" + prj2008_filename.partition("\\")[2].partition("\\")[2]
                prj2010_path = "..\\" + prj2010_filename.partition("\\")[2].partition("\\")[2]

                # add project to solution
                if not self.project_is_2010:
                    OUTFILESLN2008.write("Project(\"{19091980-2008-4CFA-1491-04CC20D8BCF9}\") = \""+\
                                            sample.project_name + "\", \"" + prj2008_path + "\", \"" + sample.project_guid + "\"\n")
                OUTFILESLN2010.write("Project(\"{19091980-2008-4CFA-1491-04CC20D8BCF9}\") = \""+\
                                            sample.project_name + "\", \"" + prj2010_path + "\", \"" + sample.project_guid + "\"\n")

                # write down dependencies
                if len(sample.dependencies) > 0:
                    if not self.project_is_2010:
                        OUTFILESLN2008.write("\tProjectSection(ProjectDependencies) = postProject\n")
                        for depend in sample.dependencies:
                            OUTFILESLN2008.write("\t\t" + all_samples[depend].project_guid + " = " + all_samples[depend].project_guid + "\n")
                        OUTFILESLN2008.write("\tEndProjectSection\n")
                        if self.write_2010_sample_dependency == True:
                            write_dependencides(OUTFILESLN2010,all_samples,sample)
                            
                if not self.project_is_2010:
                    OUTFILESLN2008.write("EndProject\n")
                OUTFILESLN2010.write("EndProject\n")

        # Close files
        if not self.project_is_2010:
            OUTFILESLN2008.write("Global\n")
            OUTFILESLN2008.write("	GlobalSection(SolutionConfigurationPlatforms) = preSolution\n")
            OUTFILESLN2008.write("		Debug|Win32 = Debug|Win32\n")
            OUTFILESLN2008.write("		Debug|x64 = Debug|x64\n")
            OUTFILESLN2008.write("		Release|Win32 = Release|Win32\n")
            OUTFILESLN2008.write("		Release|x64 = Release|x64\n")
            OUTFILESLN2008.write("	EndGlobalSection\n")
            OUTFILESLN2008.write("	GlobalSection(ProjectConfigurationPlatforms) = postSolution\n")
        OUTFILESLN2010.write("Global\n")
        OUTFILESLN2010.write("	GlobalSection(SolutionConfigurationPlatforms) = preSolution\n")
        OUTFILESLN2010.write("		Debug|Win32 = Debug|Win32\n")
        OUTFILESLN2010.write("		Debug|x64 = Debug|x64\n")
        OUTFILESLN2010.write("		Release|Win32 = Release|Win32\n")
        OUTFILESLN2010.write("		Release|x64 = Release|x64\n")
        OUTFILESLN2010.write("	EndGlobalSection\n")
        OUTFILESLN2010.write("	GlobalSection(ProjectConfigurationPlatforms) = postSolution\n")

        for sample in list(all_samples.values()):
            conf_32_name = "Win32"
            if sample.is_net:
                conf_32_name = "x86"

            if not self.project_is_2010:
                OUTFILESLN2008.write("		" + sample.project_guid + ".Debug|Win32.ActiveCfg = Debug|" + conf_32_name + "\n")
                OUTFILESLN2008.write("		" + sample.project_guid + ".Debug|Win32.Build.0 = Debug|" + conf_32_name + "\n")
                OUTFILESLN2008.write("		" + sample.project_guid + ".Debug|x64.ActiveCfg = Debug|x64\n")
                OUTFILESLN2008.write("		" + sample.project_guid + ".Debug|x64.Build.0 = Debug|x64\n")
                OUTFILESLN2008.write("		" + sample.project_guid + ".Release|Win32.ActiveCfg = Release|" + conf_32_name + "\n")
                OUTFILESLN2008.write("		" + sample.project_guid + ".Release|Win32.Build.0 = Release|" + conf_32_name + "\n")
                OUTFILESLN2008.write("		" + sample.project_guid + ".Release|x64.ActiveCfg = Release|x64\n")
                OUTFILESLN2008.write("		" + sample.project_guid + ".Release|x64.Build.0 = Release|x64\n")
            OUTFILESLN2010.write("		" + sample.project_guid + ".Debug|Win32.ActiveCfg = Debug|" + conf_32_name + "\n")
            OUTFILESLN2010.write("		" + sample.project_guid + ".Debug|Win32.Build.0 = Debug|" + conf_32_name + "\n")
            OUTFILESLN2010.write("		" + sample.project_guid + ".Debug|x64.ActiveCfg = Debug|x64\n")
            OUTFILESLN2010.write("		" + sample.project_guid + ".Debug|x64.Build.0 = Debug|x64\n")
            OUTFILESLN2010.write("		" + sample.project_guid + ".Release|Win32.ActiveCfg = Release|" + conf_32_name + "\n")
            OUTFILESLN2010.write("		" + sample.project_guid + ".Release|Win32.Build.0 = Release|" + conf_32_name + "\n")
            OUTFILESLN2010.write("		" + sample.project_guid + ".Release|x64.ActiveCfg = Release|x64\n")
            OUTFILESLN2010.write("		" + sample.project_guid + ".Release|x64.Build.0 = Release|x64\n")

        if not self.project_is_2010:
            OUTFILESLN2008.write("	EndGlobalSection\n")
            OUTFILESLN2008.write("	GlobalSection(SolutionProperties) = preSolution\n")
            OUTFILESLN2008.write("		HideSolutionNode = FALSE\n")
            OUTFILESLN2008.write("	EndGlobalSection\n")
            OUTFILESLN2008.write("EndGlobal	\n")
        OUTFILESLN2010.write("	EndGlobalSection\n")
        OUTFILESLN2010.write("	GlobalSection(SolutionProperties) = preSolution\n")
        OUTFILESLN2010.write("		HideSolutionNode = FALSE\n")
        OUTFILESLN2010.write("	EndGlobalSection\n")
        OUTFILESLN2010.write("EndGlobal	\n")

        if not self.project_is_2010:
            OUTFILESLN2008.close()
        OUTFILESLN2010.close()

        os.chdir(self.WORK_DIR)

    def remove_read_only_attributes(self):
        #-----Remove Read Only Attrib--------------------------------------------------#
        print("* Removing Read Only Attributes...")
        full_path = os.path.join(self.WORK_DIR,"Platform", "Win32" , "Redist")
        self.logger.info("Removing Read Only Attributes... (%s)" % (full_path))
        #os.system ("attrib -r -h -s /S Redist\\*.*")
        remove_readonly(full_path)

    def make_installer(self,msi_dest_path):
        """
        [dev_success,redist_success]
        """
        wix_var_file = '%sVariables.wxi'%self.redist_internal_name.replace('_','')

        [dev_success,redist_success] = [False,False]
        print("* Making Installer...")
        self.logger.info("Making Installer...")
        self.wix_inst_primitive_check()
        os.chdir(os.path.join(self.WORK_DIR,self.inst_proj_path))
        # Replace version in the WIX
        self.wix_dev_var_set()
        self.check_upgrade_install_sln()
        print("calling WIX")
        conf_name = self.internal_conf_name
        dev_success = self.build_installer(conf_name)
        print(("moving %s Msi"%conf_name))
        src = ('.\\bin\Release\en-US\\%s.msi'%self.redist_internal_name)
        dst = os.path.join( msi_dest_path ,self.final_dir,(self.product_name + '-Win' + self.vc_build_bits + "-" + self.VER + '-%s.msi'%conf_name))
        os.system(("move %s %s"%(src,dst)))
        self.dev_to_redist_hack()
        self.wix_redist_var_set()
        print("calling WIX")
        conf_name = 'Redist'
        redist_success = self.build_installer(conf_name)
        print(("moving %s Msi"%conf_name))
        os.system("move .\\bin\Release\en-US\\%s.msi %s"%(self.redist_internal_name,\
                                                          os.path.join( msi_dest_path ,self.final_dir,self.product_name + '-Win' + self.vc_build_bits + "-" + self.VER + '-%s.msi'%conf_name)))

        os.chdir(self.WORK_DIR)
        return [dev_success,redist_success]

    def build_installer(self,conf_name):
        success = False
        wix_log = 'Build%sWIX%s'%(self.redist_internal_name,conf_name)
        wix_log.replace('_','') #because outside code expects EENI in the name instead of EE_NI
        out_file = os.path.join('..\\..\\CreateRedist',self.output_dir,"%s.txt"%wix_log)
        wix_rc = subprocess.call("\"" + self.VS_INST_DIR \
            + "devenv\" %s.wixproj /Build \"release|%s"%(self.redist_internal_name, 'x86' if self.vc_build_bits=='32' else 'x64')  \
            + "\" /out " + out_file, close_fds=True)
        failed_builds = self.check_vs_report_failed(out_file)
        if failed_builds > 0 or wix_rc != 0:
            self.logger.info('Fail to build installer for %s version'%conf_name)
        else:
            success = True
        return success

    def wix_redist_var_set(self):
        """preconsdition: CWD is where wix-variables-file is stored"""
        temp = self.redist_internal_name.replace('_','')
        os.system("attrib -r Includes\\%sVariables.wxi"%temp)
        #print("setting WIX BuildPlatform")
        #regx_replace("BuildPlatform=(.*)", "BuildPlatform=" + str(vc_build_bits) + "?>", "Includes\\OpenNIVariables.wxi")
        print("setting WIX BinaryOnlyRedist=True")
        regx_replace("BinaryOnlyRedist=(.*)", "BinaryOnlyRedist=True?>", "Includes\\%sVariables.wxi"%temp)

    def wix_dev_var_set(self):
        """preconsdition: CWD is where wix-variables-file is stored"""
        print("setting WIX BinaryOnlyRedist=False")
        temp = self.redist_internal_name.replace('_','')
        os.system("attrib -r Includes\\%sVariables.wxi"%temp)
        regx_replace("BinaryOnlyRedist=(.*)", "BinaryOnlyRedist=False?>", "Includes\\%sVariables.wxi"%temp)

    def check_upgrade_install_sln(self):
        """preconsdition: CWD is where wix-variables-file is stored"""
        up_wix_file = os.path.join('..\\..\\CreateRedist',self.output_dir,"Upgrade%sWIX.txt"%(self.redist_internal_name))
        if self.VS_NEED_UPGRADE == 1:
            subprocess.call("\"" + self.VS_INST_DIR +  \
            "devenv\" %s.sln /upgrade /out "%(self.redist_internal_name) + up_wix_file, close_fds=True)

    def wix_inst_primitive_check(self):
        wixPath = os.environ.get('WIX')
        if wixPath == None:
            print('*** no WIX env. var. defined ! use set WIX=C:\Program Files\Windows Installer XML v3.5\ or similar to set the path ***')
            print('make installer is SERIOUSLY expected to fail')
            self.logger.info('It seems that WIX is not installed and therefore teh installer cannot be built.')
        else:
            print(('WIX='+wixPath))

    def dev_to_redist_hack(self):
        pass

    def check_vs_report_failed(self,file):
        lines = open(file).readlines()
        build_result = lines[-2]
        failed_builds = 0
        temp = re.search("(\d*) failed",build_result)
        if temp != None :
            failed_builds = int(temp.group(1))
        return failed_builds

    def fixing_files(self):
        """
        fixing files
        """
        #--------Fixing Files----------------------------------------------------------#
        print("* Fixing Files...")
        self.logger.info("Fixing Files...")
        for dirpath, dirnames, filenames in os.walk(os.path.join(self.WORK_DIR, "Platform", "Win32", "Redist")):
            self.fix_file('', dirpath, dirnames + filenames)

    def build_samples(self):
        """
        Build Samples.
        """
        #-------------Build Samples---------------------------------------------------#
        print("* Building Samples in release configuration......")
        self.logger.info("Building Samples in release configuration...")
        # Build project solution
        os.chdir(self.WORK_DIR + self.SAMPLES_SLN.rpartition("\\")[0])

        output_file = os.path.join(self.SCRIPT_DIR ,self.output_dir ,self.PROJECT_NAME + "SmpRelease.txt")

        if self.VS_NEED_UPGRADE == 1:
            os.system("\""+self.VS_INST_DIR + "devenv\" " +self.SAMPLES_SLN.rpartition("\\")[2]+\
                       " /upgrade > " + output_file)

        subprocess.call("\""+self.VS_INST_DIR + "devenv\" " +self.SAMPLES_SLN.rpartition("\\")[2]+\
                 " " + self.vc_build_type + " \"release|" + self.vc_build_platform + "\" /out " + output_file)

        # Get the build output
        lines = open(output_file).readlines()
        build_result = lines[-2]
        print(build_result)
        self.logger.info(build_result)
        # Check for failed build

        failed_builds = 0
        temp = re.search("(\d*) failed",build_result)

        if temp != None :
            failed_builds = int(temp.group(1))
        if failed_builds != 0:
            print("Samples Building In Release Failed!!")
            self.logger.critical("Samples Building Failed!")
            self.finish_script(1)

        print("* Building Samples in debug configuration......")
        self.logger.info("Building Samples in debug configuration...")
        # Build project solution
        os.chdir(self.WORK_DIR +self.SAMPLES_SLN.rpartition("\\")[0])

        output_file = os.path.join(self.SCRIPT_DIR ,self.output_dir ,self.PROJECT_NAME + "SmpDebug.txt")

        if self.VS_NEED_UPGRADE == 1:
            os.system("\""+self.VS_INST_DIR + "devenv\" " +self.SAMPLES_SLN.rpartition("\\")[2]+\
                     " /upgrade > " + output_file)

        subprocess.call("\""+self.VS_INST_DIR + "devenv\" " +self.SAMPLES_SLN.rpartition("\\")[2]+\
                 " " + self.vc_build_type + " \"debug|" + self.vc_build_platform + "\" /out " + output_file)

        # Get the build output
        lines = open(output_file).readlines()
        build_result = lines[-2]
        print(build_result)
        self.logger.info(build_result)
        # Check for failed build

        failed_builds = 0
        tempReResult = re.search("(\d*) failed",build_result)

        if tempReResult != None :
            failed_builds = int(tempReResult.group(1))
        if failed_builds != 0:
            print("Samples Building In Debug Failed!!")
            self.logger.critical("Samples Building Failed!")
            self.finish_script(1)

        # Build other samples
        all_samples = self.get_samples()
        for sample in list(all_samples.values()):
            if sample.is_other:
                self.build_other_proj(os.path.join(self.WORK_DIR, "Platform", "Win32", "Redist", "Samples", sample.name))

        # --------------------Delete stuff
        os.chdir(self.WORK_DIR + "\\Platform\\Win32\\Redist\\Samples\\" + self.bin_dir +"\\Release\\")
        os.system("del *.pdb")
        os.chdir(self.WORK_DIR + "\\Platform\\Win32\\Redist\\Samples\\" + self.bin_dir +"\\Debug\\")
        os.system("del *.pdb")
        os.system("del *.ilk")
        os.chdir(self.WORK_DIR + "\\Platform\\Win32\\Redist\\" + self.lib_dir + "\\")
        os.system("del nim*.*")

        os.chdir(self.WORK_DIR)

    def clean_up(self):
        temp_str = "Redist "+ self.redist_name +" Ended."
        print(temp_str)
        self.logger.info(temp_str)
        #self.finish_script(0)
class Command(object):
    def __init__(self, cmd):
        self.cmd = cmd
        self.process = None

    def run(self, timeout):
        def target():
            print('Thread started')
            self.process = subprocess.Popen(self.cmd, shell=True)
            self.process.communicate()
            print('Thread finished')

        thread = threading.Thread(target=target)
        thread.start()

        thread.join(timeout)
        if thread.is_alive():
            print('Terminating process')
            self.process.terminate()
            thread.join()
        print((self.process.returncode))



import os
import sys
import re
import time
import traceback

packageFullPath = "..\..\..\..\..\PrimeSenseVersions.nsh"

def find_package_number(findStr, text):
    for line in text:
        temp = re.search(findStr, line)
        if temp != None:
            packageNumber = temp.group(1)
            return packageNumber

def copy_files_to_repository(SourcePath,RepositoryPath, BuildDate, PackageVersion, Bits, ProjectName,
                             Major_version, Minor_version, Maintenance_version, Build_version):
    fullVersion = Major_version + "." + Minor_version + "." + Maintenance_version + "." + Build_version
    destPath = os.path.join(RepositoryPath, BuildDate + "__" + PackageVersion, "Win" + Bits,
                            ProjectName + "-" + fullVersion)
    os.system("rmdir /S /q " + destPath)
    os.system("mkdir " + destPath)
    os.system("xcopy /E /I " + SourcePath + " " + destPath)

def copy_zip_to_repository(SourcePath,RepositoryPath, BuildDate, PackageVersion, Bits, ProjectName,
                             Major_version, Minor_version, Maintenance_version, Build_version):
    fullVersion = Major_version + "." + Minor_version + "." + Maintenance_version + "." + Build_version
    destPath = os.path.join(RepositoryPath, BuildDate + "__" + PackageVersion, "Win" + Bits,
                            ProjectName + "-" + fullVersion)
    os.system("rmdir /S /q " + destPath)
    os.system("mkdir " + destPath)
    os.system("xcopy /I " + SourcePath + " " + destPath)

def open_package_file(path):
    files = open(path).readlines()
    packageNumber = find_package_number("!define PACKAGE_VER\s+\"(\S+)\"", files)
    return packageNumber

if __name__ == "__main__":
    try:
        if len(sys.argv) != 10:
            print (("Usage: copyToRepository.py <FinalPath> <RepositoryPath> <BuildDate> <bits> " \
            + "<ProjectName> <Major_version> <Minor_version> <Maintenance_version> <Build_version>"))
            sys.exit(1)

        finalPath = sys.argv[1]
        repositoryPath = sys.argv[2]
        buildDate = sys.argv[3]
        bits = sys.argv[4]
        projectName = sys.argv[5]
        major_version = sys.argv[6]
        minor_version = sys.argv[7]
        maintenance_version = sys.argv[8]
        build_version = sys.argv[9]

        packageNumber = ''
        if not(os.path.exists(packageFullPath)):
            # Redist of OpenNI openSource
            packageFullPath = "..\..\..\..\..\..\PrimeSenseVersions.nsh"
            packageNumber = open_package_file(packageFullPath)
            if packageNumber == '':
                sys.exit(1)
            copy_zip_to_repository("..\..\..\..\*.zip",repositoryPath, buildDate, packageNumber, bits,
                                 projectName, major_version, minor_version, maintenance_version, build_version)
        else:
            # Redist of OpenNI
            packageNumber = open_package_file(packageFullPath)
            if packageNumber == '':
                sys.exit(1)
            copy_files_to_repository(finalPath,repositoryPath, buildDate, packageNumber, bits,
                                 projectName, major_version, minor_version, maintenance_version, build_version)

        sys.exit(0)
    except SystemExit as e:
        sys.exit(e)
    except:
        print ((traceback.print_exc()))
        sys.exit(1)



#/***************************************************************************
#*                                                                          *
#*  OpenNI 1.x Alpha                                                        *
#*  Copyright (C) 2011 PrimeSense Ltd.                                      *
#*                                                                          *
#*  This file is part of OpenNI.                                            *
#*                                                                          *
#*  OpenNI is free software: you can redistribute it and/or modify          *
#*  it under the terms of the GNU Lesser General Public License as published*
#*  by the Free Software Foundation, either version 3 of the License, or    *
#*  (at your option) any later version.                                     *
#*                                                                          *
#*  OpenNI is distributed in the hope that it will be useful,               *
#*  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
#*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the            *
#*  GNU Lesser General Public License for more details.                     *
#*                                                                          *
#*  You should have received a copy of the GNU Lesser General Public License*
#*  along with OpenNI. If not, see <http://www.gnu.org/licenses/>.          *
#*                                                                          *
#***************************************************************************/
import os
import re

# ----------------------- MAIN -------------------------
java_header = open("org_OpenNI_NativeMethods.h")
cont = java_header.read()
java_header.close()
result = open("methods.inl", "w")
result.write("static JNINativeMethod methods[] = {\n")

while True:
    match = re.search("Method:\s*(\w*)", cont)
    if match is None:
        break
    method_name = match.group(1)
    
    match = re.search("Signature:\s*([\w\(\)\[;/]*)", cont)
    if match is None:
        break
    signature = match.group(1)
        
    match = re.search("JNIEXPORT.*JNICALL (\w*)", cont)
    if match is None:
        break
    method = match.group(1)

    result.write('\t{ "' + method_name + '", "' + signature + '", (void*)&' + method + ' },\n')
    cont = cont[match.end():];

result.write('};\n');
result.close()



#/***************************************************************************
#*                                                                          *
#*  OpenNI 1.x Alpha                                                        *
#*  Copyright (C) 2011 PrimeSense Ltd.                                      *
#*                                                                          *
#*  This file is part of OpenNI.                                            *
#*                                                                          *
#*  OpenNI is free software: you can redistribute it and/or modify          *
#*  it under the terms of the GNU Lesser General Public License as published*
#*  by the Free Software Foundation, either version 3 of the License, or    *
#*  (at your option) any later version.                                     *
#*                                                                          *
#*  OpenNI is distributed in the hope that it will be useful,               *
#*  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
#*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the            *
#*  GNU Lesser General Public License for more details.                     *
#*                                                                          *
#*  You should have received a copy of the GNU Lesser General Public License*
#*  along with OpenNI. If not, see <http://www.gnu.org/licenses/>.          *
#*                                                                          *
#***************************************************************************/
#


#-------------Imports----------------------------------------------------------#
from xml.dom.minidom import parse, parseString
from time import strftime
import logging
import glob
import os
import re
import sys
import shutil
import stat
from commands import getoutput as gop

#-------------Functions--------------------------------------------------------#

def calc_jobs_number():
    cores = 1
	
    try:
        if ostype == "Darwin":
            txt = gop('sysctl -n hw.physicalcpu')
        else:		
            txt = gop('grep "processor\W:" /proc/cpuinfo | wc -l')
			
        cores = int(txt)
    except:
        pass
       
    return str(cores * 2)

def finish_script(exit_code):
    os.chdir(SCRIPT_DIR)
    exit(exit_code)

def replace_string_in_file(findStr,repStr,filePath):
    "replaces all findStr by repStr in file filePath"
    tempName=filePath+'~~~'
    input = open(filePath)
    output = open(tempName,'w')
    for s in input:
        output.write(s.replace(findStr,repStr))
    output.close()
    input.close()
    os.remove(filePath)
    os.rename(tempName,filePath)

def regx_replace(findStr,repStr,filePath):
    "replaces all findStr by repStr in file filePath using regualr expression"
    findStrRegx = re.compile(findStr)
    tempName=filePath+'~~~'
    input = open(filePath)
    output = open(tempName,'w')
    for s in input:
        output.write(findStrRegx.sub(repStr,s))
    output.close()
    input.close()
    os.remove(filePath)
    os.rename(tempName,filePath)

def check_sample(sample_dir):
    "Checks if a sample is a tool or should be skipped, returns: 0 - Regular, 1 - Skip, 2 - Tool"
    rc = 0
    if os.path.exists(sample_dir + "/.redist"):
        redistFile = open(sample_dir + "/.redist")
    else:
        rc=0
        return rc
    redist_lines =redistFile.readlines()
    skip_re = re.compile("^SKIP=([^\|]*\|)*(" + PLATFORM + "|ALL)(\|[^\|]*)*$")
    tool_re = re.compile("^TOOL=([^\|]*\|)*(" + PLATFORM + "|ALL)(\|[^\|]*)*$")
    for line in redist_lines:
        if skip_re.search(line):
            rc = 1
            redistFile.close()
            return rc
        if tool_re.search(line):
            rc = 2
            redistFile.close()
            return rc
    redistFile.close()
    return rc

def fix_file(arg,dirname,fname):
    "Fixes paths for all the files in fname"
    for filename in fname:
        filePath = dirname + "/" + filename
        if os.path.isdir(filePath):
            continue

        ext = ['c','cpp','h','ini','cs','java']
        if filename == "Makefile" or filename.partition(".")[2] in ext:
            #print "Fixing: " + filePath
            tempName=filePath+'~~~'
            input = open(filePath)
            output = open(tempName,'w')
            for s in input:
                olds = s
                s = re.sub(r"../../../Bin",r"../Bin",s)
                s = re.sub(r"../../../../../Include",r"../../Include =/usr/include/ni",s)
                s = re.sub(r"../../../../../Samples/[\w.]+/?",r"./",s)
                s = re.sub(r"../../../../Data/SamplesConfig.xml",r"../../Config/SamplesConfig.xml",s)
                s = re.sub(r"../../Res/",r"../Res/",s)
                s = re.sub(r"include ../../Common/CommonDefs.mak",r"include ../Build/Common/CommonDefs.mak",s)
                s = re.sub(r"include ../../Common/CommonCppMakefile",r"LIB_DIRS += ../../Lib\ninclude ../Build/Common/CommonCppMakefile",s)
                s = re.sub(r"include ../../Common/CommonCSMakefile",r"LIB_DIRS += ../../Lib\ninclude ../Build/Common/CommonCSMakefile",s)
                s = re.sub(r"include ../../Common/CommonJavaMakefile",r"LIB_DIRS += ../../Lib\ninclude ../Build/Common/CommonJavaMakefile",s)

                output.write(s)
                
                #if s != olds:
                    #print "Changed : " + olds.strip("\n")
                    #print "To      : " + s.strip("\n")

            output.close()
            input.close()
            os.remove(filePath)
            os.rename(tempName,filePath)

def copy_install_script(platform, filePath, dest):
    "Copies the install script and fixing it if needed"
    input = open(filePath)
    dest_name = os.path.join(dest, os.path.basename(filePath))
    output = open(dest_name, 'w')
    
    for line in input:
        if platform == 'CE4100':
            line = re.sub(r"/var/lib/ni", r"/usr/etc/ni", line)
            
        output.write(line)
        
    input.close()
    output.close()
    os.chmod(dest_name, stat.S_IRUSR | stat.S_IXUSR | stat.S_IRGRP | stat.S_IXGRP | stat.S_IROTH | stat.S_IXOTH)
    
def execute_check(cmd, name):
    "Executes command and checks the return code. If it's not 0, stops redist."
    ret = os.system(cmd)
    if ret != 0:
        print "failed to execute: " + cmd
        print name + " Failed!"
        logger.critical(name + " Failed!")
        finish_script(1)
        

#------------Constants and globals---------------------------------------------#
DateTimeSTR = strftime("%Y-%m-%d %H:%M:%S")
DateSTR = strftime("%Y-%m-%d")
SCRIPT_DIR = os.getcwd()
# Fix to allow reletive path
WORK_DIR = os.getcwd() + "/"
os.chdir(SCRIPT_DIR)
PROJECT_NAME = "OpenNI"
ostype = os.popen('uname -s').read().rstrip()
machinetype = os.popen('uname -m').read().rstrip()

if len(sys.argv) >= 2:
    PLATFORM = sys.argv[1]
    MAKE_ARGS = 'PLATFORM=' + PLATFORM
else:
    if machinetype == "x86_64":
        PLATFORM = "x64"
    elif machinetype == "x86" or machinetype == "i386" or machinetype == "i686":
        PLATFORM = "x86"
    elif machinetype[:3] == "arm":
        PLATFORM = "Arm"
    else:
        print "Unknown platform:", machinetype
        finish_script(1)

    MAKE_ARGS = ''

MAKE_ARGS += ' -j' + calc_jobs_number()

if ostype == "Darwin":
    TARGET = "MacOSX"
else:
    TARGET = "Linux-" + PLATFORM

#-------------Log--------------------------------------------------------------#

# Create output dir
if (os.path.exists(SCRIPT_DIR + "/Output")):
    shutil.rmtree(SCRIPT_DIR + "/Output")
if (os.path.exists(SCRIPT_DIR + "/Final")):
    shutil.rmtree(SCRIPT_DIR + "/Final")
os.makedirs(SCRIPT_DIR + "/Output")
logger = logging.getLogger('myapp')
hdlr = logging.FileHandler('Output/Nightly.log')
formatter = logging.Formatter('%(asctime)s %(levelname)s %(message)s')
hdlr.setFormatter(formatter)
logger.addHandler(hdlr)
logger.setLevel(logging.INFO)

#------------Welcome Messege--------=------------------------------------------#
print "\n";
print "*********************************"
print "*   PrimeSense OpenNI Redist    *"
print "*     " + DateTimeSTR + "       *"
print "*********************************"
print
logger.info("PrimeSense OpenNI Redist Started")

print "Target:", TARGET

#--------------Take Version----------------------------------------------------#
version_file = open("../../../Include/XnVersion.h").read()
major = re.search(r"define XN_MAJOR_VERSION (\d+)", version_file).groups()[0]
minor = re.search(r"define XN_MINOR_VERSION (\d+)", version_file).groups()[0]
maintenance = re.search(r"define XN_MAINTENANCE_VERSION (\d+)", version_file).groups()[0]
build = re.search(r"define XN_BUILD_VERSION (\d+)", version_file).groups()[0]

version = major + "." + minor + "." + maintenance + "." + build
print "Version:", version

print "Num of compile jobs:", calc_jobs_number()

print

#--------------Build Project---------------------------------------------------#
print "* Building OpenNI..."
logger.info("Building OpenNI...")

# Build
#execute_check("gacutil -u OpenNI.net > " + SCRIPT_DIR + "/Output/gacutil.txt", "Remove from GAC")
execute_check('make ' + MAKE_ARGS + ' -C ' + SCRIPT_DIR + '/../Build clean > ' + SCRIPT_DIR + '/Output/Build' + PROJECT_NAME + '_clean.txt', 'Cleaning')
execute_check('make ' + MAKE_ARGS + ' -C ' + SCRIPT_DIR + '/../Build > ' + SCRIPT_DIR + '/Output/Build' + PROJECT_NAME + '.txt', 'Building')

#--------------Doxygen---------------------------------------------------------#
print "* Creating Doxygen..."
logger.info("Creating DoxyGen...")
os.chdir("../../../Source/DoxyGen");
if os.path.exists("html"):
    os.system("rm -rf html")
# Running doxygen
os.makedirs("html")
execute_check("doxygen Doxyfile > "+ SCRIPT_DIR + "/Output/EngineDoxy.txt", "Creating Documentation")

# remove unneeded files
os.system("rm -rf html/*.map html/*.md5 html/*.hhc html/*.hhk html/*.hhp")

#-------------Create Redist Dir------------------------------------------------#
print "* Creating Redist Dir..."
logger.info("Creating Redist Dir...")
os.chdir(SCRIPT_DIR + "/..")

REDIST_NAME = "OpenNI-Bin-Dev-" + TARGET + "-v" + version

REDIST_DIR = "Redist/" + REDIST_NAME

# Removing the old directory
if (os.path.exists(REDIST_DIR)):
    shutil.rmtree(REDIST_DIR)

# Creating new directory tree
os.makedirs(REDIST_DIR)
os.makedirs(REDIST_DIR + "/Bin")
os.makedirs(REDIST_DIR + "/Lib")
os.makedirs(REDIST_DIR + "/Jar")
os.makedirs(REDIST_DIR + "/Include")
os.makedirs(REDIST_DIR + "/Documentation")
os.makedirs(REDIST_DIR + "/Samples")
os.makedirs(REDIST_DIR + "/Samples/Bin")
os.makedirs(REDIST_DIR + "/Samples/Bin/" + PLATFORM + "-Debug")
os.makedirs(REDIST_DIR + "/Samples/Bin/" + PLATFORM + "-Release")
os.makedirs(REDIST_DIR + "/Samples/Build")
os.makedirs(REDIST_DIR + "/Samples/Config")
os.makedirs(REDIST_DIR + "/Samples/Res")

#-------------Copy files to redist---------------------------------------------#
print "* Copying files to redist dir..."
logger.info("Copying files to redist dir...")

#license
shutil.copy("../../GPL.txt", REDIST_DIR)
shutil.copy("../../LGPL.txt", REDIST_DIR)

#lib
if ostype == "Darwin":
    LIBS_TYPE = ".dylib"
else:
    LIBS_TYPE = ".so"

shutil.copy("Bin/" + PLATFORM + "-Release/libnimCodecs"+LIBS_TYPE, REDIST_DIR + "/Lib")
shutil.copy("Bin/" + PLATFORM + "-Release/libnimMockNodes"+LIBS_TYPE, REDIST_DIR + "/Lib")
shutil.copy("Bin/" + PLATFORM + "-Release/libnimRecorder"+LIBS_TYPE, REDIST_DIR + "/Lib")
shutil.copy("Bin/" + PLATFORM + "-Release/libOpenNI"+LIBS_TYPE, REDIST_DIR + "/Lib")
shutil.copy("Bin/" + PLATFORM + "-Release/libOpenNI.jni"+LIBS_TYPE, REDIST_DIR + "/Lib")

#bin
MonoDetected = 0
shutil.copy("Bin/" + PLATFORM + "-Release/niReg", REDIST_DIR + "/Bin")
shutil.copy("Bin/" + PLATFORM + "-Release/niLicense", REDIST_DIR + "/Bin")
if PLATFORM == 'x86' or PLATFORM == 'x64':
    if (os.path.exists("/usr/bin/gmcs")):
        shutil.copy("Bin/" + PLATFORM + "-Release/OpenNI.net.dll", REDIST_DIR + "/Bin")
        shutil.copy("Bin/" + PLATFORM + "-Release/OpenNI.net.dll", REDIST_DIR + "/Samples/Bin/" + PLATFORM + "-Debug")
        shutil.copy("Bin/" + PLATFORM + "-Release/OpenNI.net.dll", REDIST_DIR + "/Samples/Bin/" + PLATFORM + "-Release")
        MonoDetected = 1
        
# java wrapper
shutil.copy("Bin/" + PLATFORM + "-Release/org.OpenNI.jar", REDIST_DIR + "/Jar")
shutil.copy("Bin/" + PLATFORM + "-Release/org.OpenNI.jar", REDIST_DIR + "/Samples/Bin/" + PLATFORM + "-Debug")
shutil.copy("Bin/" + PLATFORM + "-Release/org.OpenNI.jar", REDIST_DIR + "/Samples/Bin/" + PLATFORM + "-Release")

#docs
shutil.copytree("../../Source/DoxyGen/html", REDIST_DIR + "/Documentation/html")

#include
for includeFile in os.listdir("../../Include"):
    if not os.path.isdir("../../Include/" + includeFile):
        shutil.copy("../../Include/" + includeFile, REDIST_DIR + "/Include")

shutil.copytree("../../Include/Linux-x86", REDIST_DIR + "/Include/Linux-x86")
shutil.copytree("../../Include/Linux-Arm", REDIST_DIR + "/Include/Linux-Arm")
shutil.copytree("../../Include/MacOSX", REDIST_DIR + "/Include/MacOSX")
shutil.copytree("Build/Common", REDIST_DIR + "/Samples/Build/Common")

# samples
samples_list = os.listdir("Build/Samples")
if '.svn' in samples_list:
    samples_list.remove('.svn')

if PLATFORM == 'CE4100':
    samples_list.remove('NiViewer')
    samples_list.remove('NiSimpleViewer')

if PLATFORM == 'Arm':
    samples_list.remove('NiUserTracker')
    samples_list.remove('NiViewer')
    samples_list.remove('NiSimpleViewer')
    samples_list.remove('NiHandTracker')
    samples_list.remove('NiUserSelection')

if (MonoDetected == 0):
    samples_list.remove("SimpleRead.net")
    samples_list.remove("SimpleViewer.net")
    samples_list.remove("UserTracker.net")

print "Samples:", samples_list

for sample in samples_list:
    shutil.copytree("../../Samples/" + sample, REDIST_DIR + "/Samples/" + sample)
    shutil.copy("Build/Samples/"+ sample + "/Makefile", REDIST_DIR + "/Samples/"+ sample)

#data
shutil.copy("../../Data/SamplesConfig.xml", REDIST_DIR + "/Samples/Config/SamplesConfig.xml")

#res
res_files = os.listdir("Build/Res")
if '.svn' in res_files:
    res_files.remove('.svn')
for res_file in res_files:
    shutil.copy("Build/Res/" + res_file, REDIST_DIR + "/Samples/Res")

# remove all .svn files
os.system("find " + REDIST_DIR + "/. | grep .svn | xargs rm -rf")

# remove all .svn files
os.system("find " + REDIST_DIR + "/Samples/. | grep .svn | xargs rm -rf")

#-----Remove Read Only Attrib--------------------------------------------------#
print "* Removing Read Only Attributes..."
logger.info("Removing Read Only Attributes...")
os.system ("chmod -R +r " + REDIST_DIR + "/*")

#--------Fixing Files----------------------------------------------------------#
print "* Fixing Files..."
logger.info("Fixing Files...")
os.path.walk(REDIST_DIR + "/Samples",fix_file,'')

#-------Creating project and solutions-----------------------------------------#
print "* Creating Makefile..."
logger.info("Creating Makefile...")

MAKEFILE = open(REDIST_DIR + "/Samples/Build/Makefile", 'w')
MAKEFILE.write("include Common/CommonDefs.mak\n\n")
MAKEFILE.write(".PHONY: all\n\n")
MAKEFILE.write("NETPROJ = \n")

MAKEFILE.write("ifneq \"$(realpath /usr/bin/gmcs)\" \"\"\n");
for sample in samples_list:
    if sample.find(".net") >0:
        MAKEFILE.write("\tNETPROJ += " + sample + "\n")
MAKEFILE.write("endif\n\n");

MAKEFILE.write("all: $(NETPROJ) ")
for sample in samples_list:
    if sample.find(".net") == -1:
        MAKEFILE.write(sample + " ")
MAKEFILE.write("\n\n")

for sample in samples_list:
    MAKEFILE.write("\n")
    MAKEFILE.write(".PHONY: "+sample+"\n")
    MAKEFILE.write(sample+":\n")
    MAKEFILE.write("\t$(MAKE) -C ../"+sample+"\n")
    
# Close files
MAKEFILE.close()

#-------Copy install script---------------------------------------------------#
print "* Copying install script..."
logger.info("Copying install script...")

copy_install_script(PLATFORM, "CreateRedist/install.sh", REDIST_DIR)

#-------------Build Samples---------------------------------------------------#
print "* Building Samples in release configuration......"
logger.info("Building Samples in release configuration...")

# Build project solution
execute_check("make " + MAKE_ARGS + " -C " + REDIST_DIR + "/Samples/Build " + " > "+SCRIPT_DIR+"/Output/BuildSmpRelease.txt", "Build samples in release")

print "* Building Samples in debug configuration......"
logger.info("Building Samples in debug configuration...")

# Build project solution
execute_check("make " + MAKE_ARGS + " CFG=Debug -C " + REDIST_DIR + "/Samples/Build > "+SCRIPT_DIR+"/Output/BuildSmpDebug.txt", "Build samples in debug")

# delete intermidiate files
for sample in samples_list:
   os.system("rm -rf " + REDIST_DIR + "/Samples/"+sample+"/" + PLATFORM + "/Debug")
   os.system("rm -rf " + REDIST_DIR + "/Samples/"+sample+"/" + PLATFORM + "/Release")

#-------------Create TAR-------------------------------------------------------#
print "* Creating tar......"
logger.info("Creating tar...")

os.makedirs(SCRIPT_DIR+"/Final")
os.chdir(SCRIPT_DIR + "/../Redist")

execute_check("tar -cjf " +SCRIPT_DIR+"/Final/" + REDIST_NAME + ".tar.bz2 " + REDIST_NAME, "Tar")

os.chdir(SCRIPT_DIR)

#-------------CleanUP----------------------------------------------------------#
print "* Redist OpenNi Ended.   !!"
logger.info("Redist OpenNi Ended.")
finish_script(0)





#/***************************************************************************
#*                                                                          *
#*  OpenNI 1.x Alpha                                                        *
#*  Copyright (C) 2011 PrimeSense Ltd.                                      *
#*                                                                          *
#*  This file is part of OpenNI.                                            *
#*                                                                          *
#*  OpenNI is free software: you can redistribute it and/or modify          *
#*  it under the terms of the GNU Lesser General Public License as published*
#*  by the Free Software Foundation, either version 3 of the License, or    *
#*  (at your option) any later version.                                     *
#*                                                                          *
#*  OpenNI is distributed in the hope that it will be useful,               *
#*  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
#*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the            *
#*  GNU Lesser General Public License for more details.                     *
#*                                                                          *
#*  You should have received a copy of the GNU Lesser General Public License*
#*  along with OpenNI. If not, see <http://www.gnu.org/licenses/>.          *
#*                                                                          *
#***************************************************************************/
import os
import subprocess
import sys
import shutil

# take script dir
SCRIPT_DIR = os.path.abspath(os.path.dirname(sys.argv[0]))

# parse command line
if len(sys.argv) < 5:
    print (("usage: ", sys.argv[0], " <32|64> <ProjDir> <SourceDir> <Name> [NeededJarFiles] [MainClass]"))
    exit(1)

if sys.argv[1] == "" or sys.argv[1] == "32":
    bin_dir = "Bin"
elif sys.argv[1] == "64":
    bin_dir = "Bin64"
else:
    print ('First argument must be "32", "64" or empty (32)')
    exit(1)
    
proj_dir = os.path.abspath(sys.argv[2])
source_dir = os.path.abspath(os.path.join(proj_dir, sys.argv[3]))
proj_name = sys.argv[4]
needed_jar_files = ""
main_class = ""
if len(sys.argv) > 5:
    needed_jar_files = sys.argv[5]
if len(sys.argv) > 6:
    main_class = sys.argv[6]

RELEASE_DIR = os.path.abspath(os.path.join(SCRIPT_DIR, "..", bin_dir, "Release"))
DEBUG_DIR = os.path.abspath(os.path.join(SCRIPT_DIR, "..", bin_dir, "Debug"))

JAR_FILE = os.path.join(RELEASE_DIR, proj_name + '.jar')
BATCH_FILE = os.path.join(RELEASE_DIR, proj_name + '.bat')

# make sure JAVA_HOME is set
JAVA_HOME = os.path.expandvars("$JAVA_HOME")
if JAVA_HOME == "":
    print ("JAVA_HOME is not set!")
    exit(1)
    
CLASS_PATH = os.path.expandvars("$CLASSPATH")

TEMP_BUILD_DIR = os.path.join(proj_dir, "bin")

# create bin dir if needed
if not os.path.exists(TEMP_BUILD_DIR):
    os.mkdir(TEMP_BUILD_DIR)
 
# build
cmd = '"' + os.path.join(JAVA_HOME, 'bin\javac.exe') + '" '
if needed_jar_files != "":
    # add class path
    cmd += '-cp "' + CLASS_PATH + ';'
    needed_list = needed_jar_files.split(';')
    for needed in needed_list:
        cmd += os.path.join(RELEASE_DIR, needed) + ';'
    cmd += '" '

cmd += '-d ' + TEMP_BUILD_DIR + ' ' + os.path.join(source_dir, '*.java')
res = subprocess.call(cmd)
if res != 0:
    print ("Failed to build!")
    exit(1)

# create JAR file
cmd = '"' + os.path.join(JAVA_HOME, 'bin\jar.exe') + '" -cf'
manifest = main_class != "" or needed_jar_files != ""
if manifest:
    # add manifest
    TEMP_MANIFEST_FILE = os.path.join(proj_dir, "Manifest.txt")
    manifest = open(TEMP_MANIFEST_FILE, 'w')
    if needed_jar_files != "":
        manifest.write("Class-Path:")
        needed_list = needed_jar_files.split(';')
        for needed in needed_list:
            manifest.write(" " + needed)
        manifest.write('\n')
    if main_class != "":
        manifest.write("Main-Class: " + main_class + "\n")
    manifest.close()
    cmd += 'm'
cmd += ' ' + JAR_FILE + ' '
if manifest:
    cmd += TEMP_MANIFEST_FILE + ' '
cmd += '-C ' + TEMP_BUILD_DIR + ' .'
res = subprocess.call(cmd)
if res != 0:
    print ("Failed to jar!")
    exit(1)

# copy jar to Bin/Debug
shutil.copy(JAR_FILE, DEBUG_DIR)
    
# create batch file (by default, windows does not open a console when double-clicking jar files)
if main_class != "":
    batch = open(BATCH_FILE, 'w')
    batch.write('java -jar ' + proj_name + '.jar\n')
    batch.close()

    # copy batch to Bin/Debug
    shutil.copy(BATCH_FILE, DEBUG_DIR)



#/***************************************************************************
#*                                                                          *
#*  OpenNI 1.x Alpha                                                        *
#*  Copyright (C) 2011 PrimeSense Ltd.                                      *
#*                                                                          *
#*  This file is part of OpenNI.                                            *
#*                                                                          *
#*  OpenNI is free software: you can redistribute it and/or modify          *
#*  it under the terms of the GNU Lesser General Public License as published*
#*  by the Free Software Foundation, either version 3 of the License, or    *
#*  (at your option) any later version.                                     *
#*                                                                          *
#*  OpenNI is distributed in the hope that it will be useful,               *
#*  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
#*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the            *
#*  GNU Lesser General Public License for more details.                     *
#*                                                                          *
#*  You should have received a copy of the GNU Lesser General Public License*
#*  along with OpenNI. If not, see <http://www.gnu.org/licenses/>.          *
#*                                                                          *
#***************************************************************************/
#
import sys
import os
import re
import time
import datetime

# ----------------------- PARAMS -------------------------
VERSION_MAJOR = 3
VERSION_MINOR = 1
VERSION_MAINTENANCE = 3
VERSION_BUILD = 1

# ---------------------- FUNCTIONS -----------------------
def regx_replace(findStr,repStr,filePath):
	"replaces all findStr by repStr in file filePath using regualr expression"
	findStrRegx = re.compile(findStr)
	tempName=filePath+'~~~'
	os.system("attrib -r " + filePath)
	input = open(filePath)
	output = open(tempName,'w')
	for s in input:
		output.write(findStrRegx.sub(repStr,s))
	output.close()
	input.close()
	os.remove(filePath)
	os.rename(tempName,filePath)

def update_self_defs (filePath):
	print "Updating self version defines: " + filePath
	regx_replace("VERSION_MAJOR = \d+\n", "VERSION_MAJOR = " + str(VERSION_MAJOR) + "\n", filePath)
	regx_replace("VERSION_MINOR = \d+\n", "VERSION_MINOR = " + str(VERSION_MINOR) + "\n", filePath)
	regx_replace("VERSION_MAINTENANCE = \d+\n", "VERSION_MAINTENANCE = " + str(VERSION_MAINTENANCE) + "\n", filePath)	
	regx_replace("VERSION_BUILD = \d+\n", "VERSION_BUILD = " + str(VERSION_BUILD) + "\n", filePath)

def update_src_ver_defs (filePath):
	print "Updating source version defines: " + filePath
	regx_replace("#define PSUSBDRV_MAJOR_VERSION (.*)", "#define PSUSBDRV_MAJOR_VERSION " + str(VERSION_MAJOR), filePath)
	regx_replace("#define PSUSBDRV_MINOR_VERSION (.*)", "#define PSUSBDRV_MINOR_VERSION " + str(VERSION_MINOR), filePath)
	regx_replace("#define PSUSBDRV_MAINTENANCE_VERSION (.*)", "#define PSUSBDRV_MAINTENANCE_VERSION " + str(VERSION_MAINTENANCE), filePath)	
	regx_replace("#define PSUSBDRV_BUILD_VERSION (.*)", "#define PSUSBDRV_BUILD_VERSION " + str(VERSION_BUILD), filePath)

def update_inf_ver_defs (filePath):
	print "Updating inf version defines: " + filePath
	regx_replace("DriverVer=(.*),(.*)", "DriverVer="+time.strftime("%m/%d/%Y")+","+str(VERSION_MAJOR)+"."+str(VERSION_MINOR)+"."+str(VERSION_MAINTENANCE)+"."+str(VERSION_BUILD), filePath)
	
# ----------------------- MAIN -------------------------
if len(sys.argv) == 5:
	VERSION_MAJOR=int(sys.argv[1])
	VERSION_MINOR=int(sys.argv[2])
	VERSION_MAINTENANCE=int(sys.argv[3])	
	VERSION_BUILD=int(sys.argv[4])

if (VERSION_MAJOR > 9):
	print "Illegal major version"
	sys.exit()

if (VERSION_MINOR > 99):
	print "Illegal minor version"
	sys.exit()

if (VERSION_MAINTENANCE > 99):
	print "Illegal maintenance version"
	sys.exit()
	
if (VERSION_BUILD > 9999):
	print "Illegal build version"
	sys.exit()

print "Going to update files to version: %d.%d.%d.%d" % (VERSION_MAJOR, VERSION_MINOR, VERSION_MAINTENANCE, VERSION_BUILD)

update_self_defs("./UpdateVersion.py")
update_src_ver_defs("./sys/PSDrvVersion.h")
update_inf_ver_defs("./inf/psdrv3.inf")

print "\n*** Done ***"
